def init(*args, **kwargs):
    pass


def capture_exception(*args, **kwargs):
    pass


def add_breadcrumb(*args, **kwargs):
    pass


def set_user(*args, **kwargs):
    pass


def set_extra(*args, **kwargs):
    pass


def set_context(*args, **kwargs):
    pass
